
#line 3 "lex.bugs.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer bugs_create_buffer
#define yy_delete_buffer bugs_delete_buffer
#define yy_flex_debug bugs_flex_debug
#define yy_init_buffer bugs_init_buffer
#define yy_flush_buffer bugs_flush_buffer
#define yy_load_buffer_state bugs_load_buffer_state
#define yy_switch_to_buffer bugs_switch_to_buffer
#define yyin bugsin
#define yyleng bugsleng
#define yylex bugslex
#define yylineno bugslineno
#define yyout bugsout
#define yyrestart bugsrestart
#define yytext bugstext
#define yywrap bugswrap
#define yyalloc bugsalloc
#define yyrealloc bugsrealloc
#define yyfree bugsfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE bugsrestart(bugsin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t bugsleng;

extern FILE *bugsin, *bugsout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE bugslex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-bugslineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < bugsleng; ++yyl )\
                    if ( bugstext[yyl] == '\n' )\
                        --bugslineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bugstext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up bugstext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via bugsrestart()), so that the user can continue scanning by
	 * just pointing bugsin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when bugstext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t bugsleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow bugswrap()'s to do buffer switches
 * instead of setting up a fresh bugsin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void bugsrestart (FILE *input_file  );
void bugs_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE bugs_create_buffer (FILE *file,int size  );
void bugs_delete_buffer (YY_BUFFER_STATE b  );
void bugs_flush_buffer (YY_BUFFER_STATE b  );
void bugspush_buffer_state (YY_BUFFER_STATE new_buffer  );
void bugspop_buffer_state (void );

static void bugsensure_buffer_stack (void );
static void bugs_load_buffer_state (void );
static void bugs_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER bugs_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE bugs_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE bugs_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE bugs_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *bugsalloc (yy_size_t  );
void *bugsrealloc (void *,yy_size_t  );
void bugsfree (void *  );

#define yy_new_buffer bugs_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        bugsensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bugs_create_buffer(bugsin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        bugsensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bugs_create_buffer(bugsin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *bugsin = (FILE *) 0, *bugsout = (FILE *) 0;

typedef int yy_state_type;

extern int bugslineno;

int bugslineno = 1;

extern char *bugstext;
#define yytext_ptr bugstext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up bugstext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	bugsleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 51
#define YY_END_OF_BUFFER 52
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[155] =
    {   0,
       38,   38,   52,   51,   41,   51,   25,   51,   51,   51,
       51,   14,   51,   15,   51,   34,   51,   30,   51,   10,
       51,   31,   51,   51,   35,   51,   48,   51,   11,   51,
        9,   51,   19,   51,   27,   51,   21,   51,   50,   51,
    16433,   12,   51,   13,   51,   32,   51,   50,   51,16433,
       50,   51,16433,   50,   51,16433,   50,   51,16433,   50,
       51,16433,   50,   51,16433,   16,   51,   51,   17,   51,
       28,   51,   38,   51,   39,   51,   41,   24,   42,   36,
       22,   33,   47,   37,   45,   48,   29,   18,   26,   20,
     8241,   50,   50,16433,   50,16433,   50,16433,   50,16433,

        8,   50,16433,   50,16433,   50,16433,   50,16433,   23,
       38,   39,   39,   40,   36,   45,   50,16433,   50,16433,
       50,16433,    7, 8241,   50,16433,   50,16433,    1,   50,
    16433,   43,    2,   50,16433,    5, 8241,    6, 8241,   50,
    16433,   50,16433,   46,   44,   50,16433,    3,   50,16433,
       50,16433,    4, 8241
    } ;

static yyconst flex_int16_t yy_accept[107] =
    {   0,
        1,    1,    1,    2,    3,    4,    5,    7,    9,   10,
       11,   12,   14,   16,   18,   20,   22,   24,   25,   27,
       29,   31,   33,   35,   37,   39,   42,   44,   46,   48,
       51,   54,   57,   60,   63,   66,   68,   69,   71,   73,
       75,   77,   78,   79,   79,   80,   80,   81,   82,   83,
       84,   85,   86,   87,   87,   88,   89,   90,   91,   91,
       92,   93,   95,   97,   99,  101,  104,  106,  108,  110,
      111,  112,  113,  114,  115,  116,  116,  117,  117,  117,
      119,  121,  123,  123,  125,  127,  129,  132,  132,  132,
      133,  136,  136,  138,  138,  140,  142,  144,  145,  146,

      148,  151,  153,  153,  155,  155
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    1,    6,    1,    7,    8,    1,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   18,   19,   20,
       21,   22,    1,    1,   23,   23,   23,   23,   24,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       25,    1,   26,   27,    1,    1,   28,   23,   23,   29,

       30,   31,   32,   33,   34,   23,   23,   35,   36,   37,
       38,   23,   23,   39,   23,   40,   23,   41,   23,   23,
       23,   23,   42,   43,   44,   45,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[46] =
    {   0,
        1,    2,    3,    3,    1,    1,    1,    1,    4,    1,
        5,    1,    1,    1,    6,    1,    6,    1,    1,    1,
        1,    1,    6,    6,    1,    1,    1,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    7,    6,    6,    6,
        6,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[113] =
    {   0,
        0,    0,  177,  176,  186,  241,   44,  164,  181,  176,
      174,  241,  241,  170,  241,  241,  241,  163,  168,   34,
      241,  241,   36,  155,  153,   50,  241,  241,  241,   51,
       35,   43,   42,   50,   27,  241,  129,  241,  241,    0,
       70,   87,  241,  137,  241,  123,  119,  241,  241,   70,
      241,   75,   78,   42,  241,  241,  241,  241,   73,  241,
        0,   69,   70,   73,   78,  109,   85,   86,   93,  241,
        0,  112,  113,  241,  241,  119,  117,  124,  108,  111,
      133,  142,  144,  241,  146,  147,  148,   99,   79,   66,
      150,  152,  241,  156,  241,  158,  160,   57,   45,  161,

      162,  164,  166,  241,  241,  198,  205,  212,  218,  225,
      232,  233
    } ;

static yyconst flex_int16_t yy_def[113] =
    {   0,
      105,    1,  106,  106,  105,  105,  105,  105,  107,  108,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  109,  105,  105,  105,  109,
       30,   30,   30,   30,   30,  105,  105,  105,  105,  110,
      111,  105,  105,  107,  105,  108,  108,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      112,   30,   30,   30,   30,   30,   30,   30,   30,  105,
      110,  111,  111,  105,  105,  105,  105,  105,  105,   30,
       66,   66,  105,  105,   66,   66,   66,  105,  105,  105,
       66,  105,  105,  105,  105,   66,   66,  105,  105,   66,

       66,   66,  105,  105,    0,  105,  105,  105,  105,  105,
      105,  105
    } ;

static yyconst flex_int16_t yy_nxt[287] =
    {   0,
        6,    7,    7,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   26,   27,   28,   29,   26,   30,   26,
       31,   26,   26,   32,   33,   34,   26,   26,   26,   26,
       35,   36,   37,   38,   39,   42,   42,   42,   52,   55,
       53,   59,   59,   79,   69,   79,   56,   54,   60,   60,
       62,   99,   62,   54,   61,   61,   61,   61,   62,   62,
       62,   67,   65,   98,   59,   62,   62,   62,   63,   66,
       73,   60,   90,   62,   64,   74,   50,   68,   42,   42,
       42,   77,   52,   76,   53,   99,   62,   62,   78,   76,

       62,   54,   62,   62,   78,   62,   62,   54,   81,   80,
       83,   62,   62,   62,   86,   98,   82,   84,   62,   62,
       62,   85,  105,   73,   90,   47,   62,  105,   74,   75,
       88,   87,   88,   77,   92,   89,   62,   89,   91,   45,
       78,   93,   62,   94,   62,   83,   78,   59,   59,   59,
       95,   59,   84,   92,   60,   60,   60,   94,   60,   59,
       93,   59,   59,   59,   95,  103,   60,  103,   60,   60,
       60,   70,  104,   58,  104,   57,   97,   96,   51,   50,
       49,   48,   47,   45,   43,  105,   41,   41,  105,  105,
      105,  105,  105,  102,  101,  105,  105,  100,   40,   40,

       40,   40,   40,   40,   40,   44,   44,   44,   44,   44,
       44,   44,   46,  105,  105,   46,   46,   46,   46,   62,
      105,   62,  105,   62,   62,   71,   71,   71,   71,  105,
       71,   71,   72,   72,   72,   72,   72,   72,   61,   61,
        5,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105
    } ;

static yyconst flex_int16_t yy_chk[287] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    7,    7,    7,   20,   23,
       20,   26,   30,   54,   35,   54,   23,   20,   26,   30,
       35,   99,   31,   20,   26,   30,   26,   30,   31,   33,
       32,   33,   31,   98,   59,   33,   32,   34,   30,   32,
       41,   59,   90,   34,   30,   41,   50,   34,   42,   42,
       42,   52,   53,   50,   53,   89,   62,   63,   52,   50,

       64,   53,   62,   63,   52,   65,   64,   53,   64,   63,
       66,   65,   67,   68,   68,   88,   65,   66,   67,   68,
       69,   67,   72,   73,   79,   47,   69,   72,   73,   46,
       76,   69,   76,   77,   81,   78,   66,   78,   80,   44,
       77,   81,   66,   82,   80,   83,   77,   85,   86,   87,
       82,   91,   83,   92,   85,   86,   87,   94,   91,   96,
       92,   97,  100,  101,   94,  102,   96,  103,   97,  100,
      101,   37,  102,   25,  103,   24,   86,   85,   19,   18,
       14,   11,   10,    9,    8,    5,    4,    3,    0,    0,
        0,    0,    0,  100,   97,    0,    0,   96,  106,  106,

      106,  106,  106,  106,  106,  107,  107,  107,  107,  107,
      107,  107,  108,    0,    0,  108,  108,  108,  108,  109,
        0,  109,    0,  109,  109,  110,  110,  110,  110,    0,
      110,  110,  111,  111,  111,  111,  111,  111,  112,  112,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[52] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 
    0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0,     };

extern int bugs_flex_debug;
int bugs_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up bugstext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *bugstext;
#line 1 "lexer_bugs.l"
#line 2 "lexer_bugs.l"
#include <gc.h>
#include "parser_bugs.h"

#line 624 "lex.bugs.c"

#define INITIAL 0
#define COMMENT 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int bugslex_destroy (void );

int bugsget_debug (void );

void bugsset_debug (int debug_flag  );

YY_EXTRA_TYPE bugsget_extra (void );

void bugsset_extra (YY_EXTRA_TYPE user_defined  );

FILE *bugsget_in (void );

void bugsset_in  (FILE * in_str  );

FILE *bugsget_out (void );

void bugsset_out  (FILE * out_str  );

yy_size_t bugsget_leng (void );

char *bugsget_text (void );

int bugsget_lineno (void );

void bugsset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int bugswrap (void );
#else
extern int bugswrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( bugstext, bugsleng, 1, bugsout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( bugsin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( bugsin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, bugsin))==0 && ferror(bugsin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(bugsin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int bugslex (void);

#define YY_DECL int bugslex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after bugstext and bugsleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 16 "lexer_bugs.l"

#line 809 "lex.bugs.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)bugsalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in bugslex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! bugsin )
			bugsin = stdin;

		if ( ! bugsout )
			bugsout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			bugsensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				bugs_create_buffer(bugsin,YY_BUF_SIZE );
		}

		bugs_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of bugstext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 106 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 241 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
goto find_rule; /* Shut up GCC warning -Wall */
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < bugsleng; ++yyl )
				if ( bugstext[yyl] == '\n' )
					   
    bugslineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 17 "lexer_bugs.l"
return VAR;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 18 "lexer_bugs.l"
return DATA;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 19 "lexer_bugs.l"
return MODEL;
	YY_BREAK
case 4:
*yy_cp = (yy_hold_char); /* undo effects of setting up bugstext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up bugstext again */
YY_RULE_SETUP
#line 20 "lexer_bugs.l"
return LENGTH;
	YY_BREAK
case 5:
*yy_cp = (yy_hold_char); /* undo effects of setting up bugstext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up bugstext again */
YY_RULE_SETUP
#line 21 "lexer_bugs.l"
return DIM;
	YY_BREAK
case 6:
*yy_cp = (yy_hold_char); /* undo effects of setting up bugstext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up bugstext again */
YY_RULE_SETUP
#line 22 "lexer_bugs.l"
return FOR;
	YY_BREAK
case 7:
*yy_cp = (yy_hold_char); /* undo effects of setting up bugstext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up bugstext again */
YY_RULE_SETUP
#line 23 "lexer_bugs.l"
return IN;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 24 "lexer_bugs.l"
return IN;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 25 "lexer_bugs.l"
return ';';
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 26 "lexer_bugs.l"
return ',';
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 27 "lexer_bugs.l"
return ':';
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 28 "lexer_bugs.l"
return '[';
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 29 "lexer_bugs.l"
return ']';
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 30 "lexer_bugs.l"
return '(';
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 31 "lexer_bugs.l"
return ')';
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 32 "lexer_bugs.l"
return '{';
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 33 "lexer_bugs.l"
return '}';
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 34 "lexer_bugs.l"
return LE;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 35 "lexer_bugs.l"
return LT;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 36 "lexer_bugs.l"
return GE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 37 "lexer_bugs.l"
return GT;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 38 "lexer_bugs.l"
return AND;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 39 "lexer_bugs.l"
return OR;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 40 "lexer_bugs.l"
return NE;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 41 "lexer_bugs.l"
return NOT;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 42 "lexer_bugs.l"
return EQ;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 43 "lexer_bugs.l"
return '=';
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 44 "lexer_bugs.l"
return '~';
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 45 "lexer_bugs.l"
return ARROW;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 46 "lexer_bugs.l"
return '+';
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 47 "lexer_bugs.l"
return '-';
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 48 "lexer_bugs.l"
return '^';
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 49 "lexer_bugs.l"
return '^';
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 50 "lexer_bugs.l"
return '*';
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 51 "lexer_bugs.l"
return '/';
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 53 "lexer_bugs.l"
{
    /* Special operators, e.g. %*% for matrix multiplication */
	int len = strlen(bugstext);
	int sz = sizeof(char) * (len+1);
	bugslval.stringptr = malloc(sz);
	memcpy(bugslval.stringptr, bugstext, sz);
    bugslval.stringptr[sz-1] = '\0';
	return SPECIAL;
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 63 "lexer_bugs.l"
BEGIN(COMMENT);
	YY_BREAK
case 38:
/* rule 38 can match eol */
YY_RULE_SETUP
#line 64 "lexer_bugs.l"
/* Eat up anything that's not a '*'   */
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 65 "lexer_bugs.l"
/* Eat up '*'s not followed by a '/'  */
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 66 "lexer_bugs.l"
BEGIN(INITIAL);
	YY_BREAK
case 41:
/* rule 41 can match eol */
YY_RULE_SETUP
#line 68 "lexer_bugs.l"
/* Eat whitespace */
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
#line 69 "lexer_bugs.l"
/* Eat comments */
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 71 "lexer_bugs.l"
{
  bugslval.val = atof(bugstext); return DOUBLE;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 74 "lexer_bugs.l"
{
  bugslval.val = atof(bugstext); return DOUBLE;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 77 "lexer_bugs.l"
{
  bugslval.val = atof(bugstext); return DOUBLE;
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 80 "lexer_bugs.l"
{
  bugslval.val = atof(bugstext); return DOUBLE;
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 83 "lexer_bugs.l"
{
  bugslval.val = atof(bugstext); return DOUBLE;
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 86 "lexer_bugs.l"
{
  bugslval.val = atof(bugstext); return DOUBLE;
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 91 "lexer_bugs.l"
{
	int len, sz;
	len = strlen(bugstext);
	sz = sizeof(char) * (len+1);
	bugslval.stringptr = malloc(sz);
	memcpy(bugslval.stringptr, bugstext, sz);
	bugslval.stringptr[sz-1] = '\0';
  	return FUNC;
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 101 "lexer_bugs.l"
{
	int len, sz;
	len = strlen(bugstext);
	sz = sizeof(char) * (len+1);
	bugslval.stringptr = malloc(sz);
	memcpy(bugslval.stringptr, bugstext, sz);
	bugslval.stringptr[sz-1] = '\0';
  	return NAME;
}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(COMMENT):
#line 111 "lexer_bugs.l"
yyterminate();
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 113 "lexer_bugs.l"
ECHO;
	YY_BREAK
#line 1244 "lex.bugs.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed bugsin at a new source and called
			 * bugslex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = bugsin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( bugswrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * bugstext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of bugslex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			bugsrestart(bugsin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) bugsrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 106 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 106 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 105);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up bugstext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --bugslineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					bugsrestart(bugsin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( bugswrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve bugstext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    bugslineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void bugsrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        bugsensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            bugs_create_buffer(bugsin,YY_BUF_SIZE );
	}

	bugs_init_buffer(YY_CURRENT_BUFFER,input_file );
	bugs_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void bugs_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		bugspop_buffer_state();
	 *		bugspush_buffer_state(new_buffer);
     */
	bugsensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	bugs_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (bugswrap()) processing, but the only time this flag
	 * is looked at is after bugswrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void bugs_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	bugsin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE bugs_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) bugsalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bugs_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) bugsalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in bugs_create_buffer()" );

	b->yy_is_our_buffer = 1;

	bugs_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with bugs_create_buffer()
 * 
 */
    void bugs_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		bugsfree((void *) b->yy_ch_buf  );

	bugsfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a bugsrestart() or at EOF.
 */
    static void bugs_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	bugs_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then bugs_init_buffer was _probably_
     * called from bugsrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void bugs_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		bugs_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void bugspush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	bugsensure_buffer_stack();

	/* This block is copied from bugs_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from bugs_switch_to_buffer. */
	bugs_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void bugspop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	bugs_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		bugs_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void bugsensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)bugsalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in bugsensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)bugsrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in bugsensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE bugs_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) bugsalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bugs_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	bugs_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to bugslex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       bugs_scan_bytes() instead.
 */
YY_BUFFER_STATE bugs_scan_string (yyconst char * yystr )
{
    
	return bugs_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to bugslex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE bugs_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) bugsalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in bugs_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = bugs_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in bugs_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bugstext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		bugstext[bugsleng] = (yy_hold_char); \
		(yy_c_buf_p) = bugstext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		bugsleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int bugsget_lineno  (void)
{
        
    return bugslineno;
}

/** Get the input stream.
 * 
 */
FILE *bugsget_in  (void)
{
        return bugsin;
}

/** Get the output stream.
 * 
 */
FILE *bugsget_out  (void)
{
        return bugsout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t bugsget_leng  (void)
{
        return bugsleng;
}

/** Get the current token.
 * 
 */

char *bugsget_text  (void)
{
        return bugstext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void bugsset_lineno (int  line_number )
{
    
    bugslineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see bugs_switch_to_buffer
 */
void bugsset_in (FILE *  in_str )
{
        bugsin = in_str ;
}

void bugsset_out (FILE *  out_str )
{
        bugsout = out_str ;
}

int bugsget_debug  (void)
{
        return bugs_flex_debug;
}

void bugsset_debug (int  bdebug )
{
        bugs_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from bugslex_destroy(), so don't allocate here.
     */

    /* We do not touch bugslineno unless the option is enabled. */
    bugslineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    bugsin = stdin;
    bugsout = stdout;
#else
    bugsin = (FILE *) 0;
    bugsout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * bugslex_init()
     */
    return 0;
}

/* bugslex_destroy is for both reentrant and non-reentrant scanners. */
int bugslex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		bugs_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		bugspop_buffer_state();
	}

	/* Destroy the stack itself. */
	bugsfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    bugsfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * bugslex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *bugsalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *bugsrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void bugsfree (void * ptr )
{
	free( (char *) ptr );	/* see bugsrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 113 "lexer_bugs.l"




